summaryrefslogtreecommitdiffstats
path: root/ksysguard/ksysguardd/Linux
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-11-06 02:28:57 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-11-06 02:28:57 -0600
commit7574a7287e2e121c9d5c91a5f4ea38c5b3ae2a04 (patch)
treeb7c6396f4f7fe78dcd49424bff707e977541de18 /ksysguard/ksysguardd/Linux
parent66c0fa70796c1989a9f3adb0c5c0ad799ade48ca (diff)
downloadtdebase-7574a7287e2e121c9d5c91a5f4ea38c5b3ae2a04.tar.gz
tdebase-7574a7287e2e121c9d5c91a5f4ea38c5b3ae2a04.zip
Additional kde to tde renaming
Diffstat (limited to 'ksysguard/ksysguardd/Linux')
-rw-r--r--ksysguard/ksysguardd/Linux/ProcessList.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/ksysguard/ksysguardd/Linux/ProcessList.c b/ksysguard/ksysguardd/Linux/ProcessList.c
index b267c7005..1eba1f6cc 100644
--- a/ksysguard/ksysguardd/Linux/ProcessList.c
+++ b/ksysguard/ksysguardd/Linux/ProcessList.c
@@ -40,7 +40,7 @@
#define BUFSIZE 1024
#define TAGSIZE 32
-#define KDEINITLEN strlen( "kdeinit: " )
+#define KDEINITLEN strlen( "tdeinit: " )
static CONTAINER ProcessList = 0;
@@ -287,9 +287,9 @@ static int updateProcess( int pid )
if ( fclose( fd ) )
return -1;
- /* Ugly hack to "fix" program name for kdeinit launched programs. */
- if ( strcmp( ps->name, "kdeinit" ) == 0 &&
- strncmp( ps->cmdline, "kdeinit: ", KDEINITLEN ) == 0 &&
+ /* Ugly hack to "fix" program name for tdeinit launched programs. */
+ if ( strcmp( ps->name, "tdeinit" ) == 0 &&
+ strncmp( ps->cmdline, "tdeinit: ", KDEINITLEN ) == 0 &&
strcmp( ps->cmdline + KDEINITLEN, "Running..." ) != 0 ) {
size_t len;
char* end = strchr( ps->cmdline + KDEINITLEN, ' ' );